@@ -6,8 +6,11 @@ import uuid
 ACT_UUID_NAMESPACE = uuid.UUID("6b159598-b585-11e7-a8e7-e83935122d71")
 FACT_IS_SOURCE = "FactIsSource"
 FACT_IS_DESTINATION = "FactIsDestination"
-ACCESS_MODES = ["Public", "RoleBased", "Explicit"]
-DEFAULT_ACCESS_MODE = "RoleBased"
+ACCESS_MODES_PUBLIC = "Public"
+ACCESS_MODES_ROLEBASED = "RoleBased"
+ACCESS_MODES_EXPLICIT = "Explicit"
+ACCESS_MODES = [ACCESS_MODES_PUBLIC, ACCESS_MODES_ROLEBASED, ACCESS_MODES_EXPLICIT]
+DEFAULT_ACCESS_MODE = ACCESS_MODES_ROLEBASED
 BIDIRECTIONAL_FACT = "BiDirectional"
 DEFAULT_OBJECT_VALIDATOR = r"(.|\n)*"
 DEFAULT_FACT_VALIDATOR = None
